API Gateway Common
==================

Minos Boilerplate contains all the boilerplate you need to create a Minos Python package.


Credits
-------

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter)  and the [Minos Package](https://github.com/Clariteia/minos-pypackage) project template.
